/* 
-----------------------------------------------------------------------------
File: ds.groovy
Author: Karl Bishop (kfbishop@us.ibm.com)
-----------------------------------------------------------------------------
Service to provide full schema for a data source
-----------------------------------------------------------------------------
(C) Copyright IBM Corp. 2008 All rights reserved.

You may only copy, modify, and distribute these samples internally.
These samples have not been tested under all conditions and are provided
to you by IBM without obligation of support of any kind.

IBM PROVIDES THESE SAMPLES "AS IS" SUBJECT TO ANY STATUTORY WARRANTIES THAT
CANNOT BE EXCLUDED. IBM MAKES NO WARRANTIES OR CONDITIONS, EITHER EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OR
CONDITIONS OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND
NON-INFRINGEMENT REGARDING THESE SAMPLES OR TECHNICAL SUPPORT, IF ANY.
-----------------------------------------------------------------------------
*/

/*
* Obtain all available DataSources
* Returns:
*   ItemFileReadStore Json object, with hierarchical format
*   {"label":"uid","identifier":"uid","items":[{"uid":"sample"}]}
*/
def onList() {
    logger.INFO {'onList called'};
    def dbs = invokeMethod("dba", "getDataSources", null)
    def map = ['label':'uid', 'identifier':'uid']
    def items = []
    dbs.each { items << ['uid': it] }
    map.put('items', items)
    invokeMethod('sendResponse', 'json', map)
    logger.INFO {'onList finished'}
}

/*
* Obtain details for provided DataSource
* Args:
*   dsId          ; (String) ID of DS to use
*   showSysTables : (boolean) show system level table with application tables?
* Returns:
*   ItemFileReadStore Json object, with hierarchical format
*/
def onRetrieve() {
	def dbId = request.params.dsId[]
	def showSysTables = request.params.showSysTables[];
	logger.INFO {"onRetrieve called for: ${dbId} (${showSysTables})"}
    def schemas = invokeMethod("dba", "getSchemas", dbId, showSysTables )

    def map = ['label':'name', 'identifier':'uid' ]
    def items = []
    for( schema in schemas ) {
        def schemaItem = ['uid':schema, 'name':schema, 'type':'schema'] 
        logger.INFO{ "schemaItem = ${schemaItem}" }
        // Walk the tables, add a reference in children and the obj to the main array
        def schemaChildren = []
        def typeMap = [:]
        def tables = invokeMethod("dba", "getTables", dbId, schema )
        for( table in tables ) { 
            logger.INFO {"table = ${table.uid} - ${table.type}"}
            if ( typeMap.get( table.tableType ) == null ) {
                typeMap.put( table.tableType, [ table ] )
            } else {
                typeMap.get( table.tableType ) << table
            }
        }
        //-- Walk tableTypes and
        typeMap.each {
            schemaChildren << [
                'uid'      : "${schema}_${it.key}",
                'type'     : 'folder',
                'name'     : it.key,
                'children' : it.value
            ]
        }
        //-- If there are defined type children, add them to the schema obj.
        if ( schemaChildren.size() > 0 ) {
            schemaItem.put('children', schemaChildren)
        }
        // Put the schema on the main items array
        items << schemaItem
    }
    map.put('items',items)
    invokeMethod('sendResponse', 'json', map)
    logger.INFO {'onRetrieve finished'}
}

