/**
 * onList: GET (Collection)
 *
 * @success 200 Returns a list of all cars
 * @failure 503 systems down for maintenance
 * @format application/json
 * @example
 * [
 *   {
 *     id: id,
 *     make: String,
 *     model: String,
 *     year: YYYY,
 *     number: XX,
 *     driver: {
 *       // Driver object
 *     },
 *     team: {
 *       // Team object
 *     }
 *   },
 *   ...
 * ]
 */
def onList() {
  logger.INFO {"List starting"}
  // Extract all cars from storage and return
}

/**
 * onRetrieve: GET (Singleton), with possible binding extensions.
 *
 * @success 200 Returns car specific data for a given ID
 * @failure 503 systems down for maintenance
 * @format application/json
 * @example
 * {
 *     id: id,
 *     make: String,
 *     model: String,
 *     year: YYYY,
 *     number: XX,
 *     driver: {
 *       // Driver object
 *     },
 *     team: {
 *       // Team object
 *     }
 * }
 * 
 */
def onRetrieve() {
  // Get the ID of car to get, this param is fixed
  def carId = request.params.carId[]
  logger.INFO {"Retrieve starting for: ${carId}"}
  request.status = java.net.HttpURLConnection.HTTP_BAD_METHOD
  request.view = 'error'
  request.error.message = "Method not supported"
  render()
  // Extract car from storage and return data
}

/**
 * onCreate: POST (add)
 *
 * @success 201 Car object created
 * @failure 503 systems down for maintenance
 * @format application/json
 * @example
 * {
 *     make: String,
 *     model: String,
 *     year: YYYY,
 *     number: XX,
 *     driver: {
 *       // Driver object
 *     },
 *     team: {
 *       // Team object
 *     }
 * }
 * 
 */
def onCreate() {
  // The new data for the record with could be in any param
  def carData = request.params.carData[]
  logger.INFO {"Create starting"}
  // Insert a new car into storage.
  // Need to return the ID of the new car
}

 /**
  * onUpdate: PUT
  *
  * @success 201 Car object created
  * @failure 503 systems down for maintenance
  * @format application/json
  * @example
  * {
  *     id: id,
  *     make: String,
  *     model: String,
  *     year: YYYY,
  *     number: XX,
  *     driver: {
  *       // Driver object
  *     },
  *     team: {
  *       // Team object
  *     }
  * }
  * 
  */
def onUpdate() {
  // Get the ID of car to update, this param is fixed
  def carId = request.params.carId[]
  logger.INFO {"Update starting for: ${carId}"}
  // The data to update the record with could be in any param
  def carData = request.params.someData[]
  // Update data for existing car
}

  /**
   * onDelete: DELETE
   *
   * @success 200 Success
   * @failure 503 systems down for maintenance
   * @format application/json
   * 
   */
def onDelete() {
  // Get the ID of car to delete, this param is fixed
  def carId = request.params.carId[]
  logger.INFO {"Delete starting for: ${carId}"}
  // Delete the car based on ID
  response.status = HttpURLConnection.HTTP_METHOD_NOT_FOUND
}
